==> rer.structured_content-1.7.1.tar.gz: rer.structured_content-1.7.1/setup.py <==
# -*- coding: utf-8 -*-
"""
This module contains the tool of rer.structured_content
"""
import os
from setuptools import setup, find_packages

version = '1.7.1'

tests_require=['zope.testing']

setup(name='rer.structured_content',
      version=version,
      description="A simple folderish page content for Plone",
      long_description=(open("README.txt").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read()),
                       
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        'Framework :: Plone',
        'Programming Language :: Python',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Development Status :: 4 - Beta',
        ],
      keywords='plonegov content structured document',
      author='RedTurtle Technology',
      author_email='sviluppoplone@redturtle.net',
      url='http://plone.org/products/rer.structured_content',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['rer', ],
      include_package_data=True,
      zip_safe=False,
      install_requires=['setuptools',
                        # -*- Extra requirements: -*-
                        ],
      tests_require=tests_require,
      extras_require=dict(tests=tests_require),
      test_suite = 'rer.structured_content.tests.test_docs.test_suite',
      entry_points="""
      # -*- entry_points -*- 
      [z3c.autoinclude.plugin]
      target = plone
      """,
      )

==> rer.structured_content-1.9.1.tar.gz: rer.structured_content-1.9.1/setup.py <==
# -*- coding: utf-8 -*-
"""
This module contains the tool of rer.structured_content
"""
import os
from setuptools import setup, find_packages

version = '1.9.1'

tests_require=['zope.testing']

setup(name='rer.structured_content',
      version=version,
      description="A simple folderish page content for Plone",
      long_description=open("README.txt").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        'Framework :: Plone',
        'Programming Language :: Python',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Development Status :: 4 - Beta',
        ],
      keywords='plonegov content structured document',
      author='RedTurtle Technology',
      author_email='sviluppoplone@redturtle.net',
      url='http://plone.org/products/rer.structured_content',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['rer', ],
      include_package_data=True,
      zip_safe=False,
      install_requires=['setuptools',
                        # -*- Extra requirements: -*-
                        ],
      tests_require=tests_require,
      extras_require=dict(tests=tests_require),
      test_suite = 'rer.structured_content.tests.test_docs.test_suite',
      entry_points="""
      # -*- entry_points -*-
      [z3c.autoinclude.plugin]
      target = plone
      """,
      )
